0.7.0 - Cohen project started
-----------------------------

General:
    - lots of refactoring
    - removed lots of Coherence stuff
    - moved to lxml instead of (c)ElementTree
    - Twisted >= 14.0 is now required
    - livestreamer is now required
    - cleanups and fixes

Backends:
    - twitch.tv backend added


0.0.1 - 0.7.0 - Coherence project
---------------------------------

Changelog skipped